@@ -46,7 +46,7 @@ class ClusterClient(NamespacedClient):
         """
         Provides explanations for shard allocations in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-allocation-explain.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-allocation-explain.html>`_
 
         :param current_node: Specifies the node ID or the name of the node to only explain
             a shard that is currently located on the specified node.
@@ -113,10 +113,11 @@ class ClusterClient(NamespacedClient):
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Deletes component templates. Component templates are building blocks for constructing
-        index templates that specify index mappings, settings, and aliases.
+        Delete component templates. Deletes component templates. Component templates
+        are building blocks for constructing index templates that specify index mappings,
+        settings, and aliases.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/indices-component-template.html>`_
 
         :param name: Comma-separated list or wildcard expression of component template
             names used to limit the request.
@@ -166,7 +167,7 @@ class ClusterClient(NamespacedClient):
         """
         Clears cluster voting config exclusions.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/voting-config-exclusions.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/voting-config-exclusions.html>`_
 
         :param wait_for_removal: Specifies whether to wait for all excluded nodes to
             be removed from the cluster before clearing the voting configuration exclusions
@@ -211,9 +212,10 @@ class ClusterClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> HeadApiResponse:
         """
-        Returns information about whether a particular component template exist
+        Check component templates. Returns information about whether a particular component
+        template exists.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/indices-component-template.html>`_
 
         :param name: Comma-separated list of component template names used to limit the
             request. Wildcard (*) expressions are supported.
@@ -266,9 +268,9 @@ class ClusterClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Retrieves information about component templates.
+        Get component templates. Retrieves information about component templates.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/indices-component-template.html>`_
 
         :param name: Comma-separated list of component template names used to limit the
             request. Wildcard (`*`) expressions are supported.
@@ -332,7 +334,7 @@ class ClusterClient(NamespacedClient):
         Returns cluster-wide settings. By default, it returns only settings that have
         been explicitly defined.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-get-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-get-settings.html>`_
 
         :param flat_settings: If `true`, returns settings in flat format.
         :param include_defaults: If `true`, returns default cluster settings from the
@@ -422,7 +424,7 @@ class ClusterClient(NamespacedClient):
         by the worst shard status. The cluster status is controlled by the worst index
         status.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-health.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-health.html>`_
 
         :param index: Comma-separated list of data streams, indices, and index aliases
             used to limit the request. Wildcard expressions (`*`) are supported. To target
@@ -524,9 +526,9 @@ class ClusterClient(NamespacedClient):
         pretty: t.Optional[bool] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Returns different information about the cluster.
+        Get cluster info. Returns basic information about the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-info.html>`_
 
         :param target: Limits the information returned to the specific target. Supports
             a comma-separated list, such as http,ingest.
@@ -575,7 +577,7 @@ class ClusterClient(NamespacedClient):
         update, the activity of this task might be reported by both task api and pending
         cluster tasks API.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-pending.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-pending.html>`_
 
         :param local: If `true`, the request retrieves information from the local node
             only. If `false`, information is retrieved from the master node.
@@ -623,7 +625,7 @@ class ClusterClient(NamespacedClient):
         """
         Updates the cluster voting config exclusions by node ids or node names.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/voting-config-exclusions.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/voting-config-exclusions.html>`_
 
         :param node_ids: A comma-separated list of the persistent ids of the nodes to
             exclude from the voting configuration. If specified, you may not also specify
@@ -683,24 +685,25 @@ class ClusterClient(NamespacedClient):
         body: t.Optional[t.Dict[str, t.Any]] = None,
     ) -> ObjectApiResponse[t.Any]:
         """
-        Creates or updates a component template. Component templates are building blocks
-        for constructing index templates that specify index mappings, settings, and aliases.
-        An index template can be composed of multiple component templates. To use a component
-        template, specify it in an index template’s `composed_of` list. Component templates
-        are only applied to new data streams and indices as part of a matching index
-        template. Settings and mappings specified directly in the index template or the
-        create index request override any settings or mappings specified in a component
-        template. Component templates are only used during index creation. For data streams,
-        this includes data stream creation and the creation of a stream’s backing indices.
-        Changes to component templates do not affect existing indices, including a stream’s
-        backing indices. You can use C-style `/* *\\/` block comments in component templates.
+        Create or update a component template. Creates or updates a component template.
+        Component templates are building blocks for constructing index templates that
+        specify index mappings, settings, and aliases. An index template can be composed
+        of multiple component templates. To use a component template, specify it in an
+        index template’s `composed_of` list. Component templates are only applied to
+        new data streams and indices as part of a matching index template. Settings and
+        mappings specified directly in the index template or the create index request
+        override any settings or mappings specified in a component template. Component
+        templates are only used during index creation. For data streams, this includes
+        data stream creation and the creation of a stream’s backing indices. Changes
+        to component templates do not affect existing indices, including a stream’s backing
+        indices. You can use C-style `/* *\\/` block comments in component templates.
         You can include comments anywhere in the request body except before the opening
         curly bracket.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/indices-component-template.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/indices-component-template.html>`_
 
         :param name: Name of the component template to create. Elasticsearch includes
-            the following built-in component templates: `logs-mappings`; 'logs-settings`;
+            the following built-in component templates: `logs-mappings`; `logs-settings`;
             `metrics-mappings`; `metrics-settings`;`synthetics-mapping`; `synthetics-settings`.
             Elastic Agent uses these templates to configure backing indices for its data
             streams. If you use Elastic Agent and want to overwrite one of these templates,
@@ -786,7 +789,7 @@ class ClusterClient(NamespacedClient):
         """
         Updates the cluster settings.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-update-settings.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-update-settings.html>`_
 
         :param flat_settings: Return settings in flat format (default: false)
         :param master_timeout: Explicit operation timeout for connection to master node
@@ -842,7 +845,7 @@ class ClusterClient(NamespacedClient):
         cluster information. It returns connection and endpoint information keyed by
         the configured remote cluster alias.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-remote-info.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-remote-info.html>`_
         """
         __path_parts: t.Dict[str, str] = {}
         __path = "/_remote/info"
@@ -887,7 +890,7 @@ class ClusterClient(NamespacedClient):
         """
         Allows to manually change the allocation of individual shards in the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-reroute.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-reroute.html>`_
 
         :param commands: Defines the commands to perform.
         :param dry_run: If true, then the request simulates the operation only and returns
@@ -974,7 +977,7 @@ class ClusterClient(NamespacedClient):
         """
         Returns a comprehensive information about the state of the cluster.
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-state.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-state.html>`_
 
         :param metric: Limit the information returned to the specified metrics
         :param index: A comma-separated list of index names; use `_all` or empty string
@@ -1050,8 +1053,8 @@ class ClusterClient(NamespacedClient):
         node_id: t.Optional[t.Union[str, t.Sequence[str]]] = None,
         error_trace: t.Optional[bool] = None,
         filter_path: t.Optional[t.Union[str, t.Sequence[str]]] = None,
-        flat_settings: t.Optional[bool] = None,
         human: t.Optional[bool] = None,
+        include_remotes: t.Optional[bool] = None,
         pretty: t.Optional[bool] = None,
         timeout: t.Optional[t.Union[str, t.Literal[-1], t.Literal[0]]] = None,
     ) -> ObjectApiResponse[t.Any]:
@@ -1060,11 +1063,11 @@ class ClusterClient(NamespacedClient):
         size, memory usage) and information about the current nodes that form the cluster
         (number, roles, os, jvm versions, memory usage, cpu and installed plugins).
 
-        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.15/cluster-stats.html>`_
+        `<https://www.elastic.co/guide/en/elasticsearch/reference/8.16/cluster-stats.html>`_
 
         :param node_id: Comma-separated list of node filters used to limit returned information.
             Defaults to all nodes in the cluster.
-        :param flat_settings: If `true`, returns settings in flat format.
+        :param include_remotes: Include remote cluster data into the response
         :param timeout: Period to wait for each node to respond. If a node does not respond
             before its timeout expires, the response does not include its stats. However,
             timed out nodes are included in the response’s `_nodes.failed` property.
@@ -1082,10 +1085,10 @@ class ClusterClient(NamespacedClient):
             __query["error_trace"] = error_trace
         if filter_path is not None:
             __query["filter_path"] = filter_path
-        if flat_settings is not None:
-            __query["flat_settings"] = flat_settings
         if human is not None:
             __query["human"] = human
+        if include_remotes is not None:
+            __query["include_remotes"] = include_remotes
         if pretty is not None:
             __query["pretty"] = pretty
         if timeout is not None:
